@@ -12,9 +12,8 @@ from recipe.exceptions import BadIngredient, BadRecipe, InvalidColumnError
 from recipe.ingredients import Dimension, Filter, Ingredient, Metric, InvalidIngredient
 from recipe.schemas import shelf_schema
 from recipe.schemas.parsed_constructors import create_ingredient_from_parsed
-from recipe.schemas.config_constructors import create_ingredient_from_config
 
-from recipe.schemas.lark_grammar import SQLAlchemyBuilder
+from recipe.schemas.expression_grammar import SQLAlchemyBuilder
 
 _POP_DEFAULT = object()
 
@@ -22,14 +21,7 @@ _POP_DEFAULT = object()
 def ingredient_from_validated_dict(ingr_dict, selectable, builder=None):
     """Create an ingredient object from a validated ingredient schema"""
     try:
-        version = ingr_dict.pop("_version", "1")
-        if version == "1":
-            return create_ingredient_from_config(ingr_dict, selectable)
-        else:
-            return create_ingredient_from_parsed(ingr_dict, builder)
-    except InvalidColumnError as e:
-        error = {"type": "invalid_column", "extra": {"column_name": e.column_name}}
-        return InvalidIngredient(error=error)
+        return create_ingredient_from_parsed(ingr_dict, builder)
     except VisitError as e:
         # Lark returns the InvalidColumnError wrapped in a VisitError
         if isinstance(e.orig_exc, InvalidColumnError):
